Crate llua

source · []

Re-exports

pub use corepack;
pub use crate::ffi::lua_Alloc;
pub use crate::ffi::lua_CFunction;
pub use crate::ffi::lua_Hook;
pub use crate::ffi::lua_Integer;
pub use crate::ffi::lua_Number;
pub use crate::ffi::CFunction;
pub use crate::ffi::LUA_REGISTRYINDEX;

Modules

Macros

Structs

Enums

Arithmetic operations for lua_arith.

Comparison operations for lua_compare.

Options for the Lua garbage collector.

Status of a Lua state.

Represents all possible Lua data types.

Constants

A value that will never be returned by reference.

The result of reference for nil values.

Traits

Trait for types that can be taken from the Lua stack.

Trait for types that can be pushed onto the stack of a Lua s.

Type Definitions