pub trait ToLua {
    const IS_TOP: bool = false;

    fn to_lua(self, s: &State);
}
Trait for types that can be pushed onto the stack of a Lua s.

It is important that implementors of this trait ensure that to_lua behaves like one of the lua_push* functions for consistency.

Provided Associated Constants

Required Methods

Pushes a value of type Self onto the stack of a Lua s.

Implementations on Foreign Types

Implementors