Trait for types that can be pushed onto the stack of a Lua s.
It is important that implementors of this trait ensure that to_lua
behaves like one of the lua_push* functions for consistency.
Trait for types that can be pushed onto the stack of a Lua s.
It is important that implementors of this trait ensure that to_lua
behaves like one of the lua_push* functions for consistency.